import { CompactBitArray } from "../../../crypto/multisig/v1beta1/multisig";
import { Any } from "../../../../google/protobuf/any";
import { BinaryReader, BinaryWriter } from "../../../../binary";
import { DeepPartial } from "../../../../helpers";
/**
 * SignMode represents a signing mode with its own security guarantees.
 *
 * This enum should be considered a registry of all known sign modes
 * in the Cosmos ecosystem. Apps are not expected to support all known
 * sign modes. Apps that would like to support custom  sign modes are
 * encouraged to open a small PR against this file to add a new case
 * to this SignMode enum describing their sign mode so that different
 * apps have a consistent version of this enum.
 */
export declare enum SignMode {
    /**
     * SIGN_MODE_UNSPECIFIED - SIGN_MODE_UNSPECIFIED specifies an unknown signing mode and will be
     * rejected.
     */
    SIGN_MODE_UNSPECIFIED = 0,
    /**
     * SIGN_MODE_DIRECT - SIGN_MODE_DIRECT specifies a signing mode which uses SignDoc and is
     * verified with raw bytes from Tx.
     */
    SIGN_MODE_DIRECT = 1,
    /**
     * SIGN_MODE_TEXTUAL - SIGN_MODE_TEXTUAL is a future signing mode that will verify some
     * human-readable textual representation on top of the binary representation
     * from SIGN_MODE_DIRECT.
     *
     * Since: cosmos-sdk 0.50
     */
    SIGN_MODE_TEXTUAL = 2,
    /**
     * SIGN_MODE_DIRECT_AUX - SIGN_MODE_DIRECT_AUX specifies a signing mode which uses
     * SignDocDirectAux. As opposed to SIGN_MODE_DIRECT, this sign mode does not
     * require signers signing over other signers' `signer_info`.
     *
     * Since: cosmos-sdk 0.46
     */
    SIGN_MODE_DIRECT_AUX = 3,
    /**
     * SIGN_MODE_LEGACY_AMINO_JSON - SIGN_MODE_LEGACY_AMINO_JSON is a backwards compatibility mode which uses
     * Amino JSON and will be removed in the future.
     */
    SIGN_MODE_LEGACY_AMINO_JSON = 127,
    /**
     * SIGN_MODE_EIP_191 - SIGN_MODE_EIP_191 specifies the sign mode for EIP 191 signing on the Cosmos
     * SDK. Ref: https://eips.ethereum.org/EIPS/eip-191
     *
     * Currently, SIGN_MODE_EIP_191 is registered as a SignMode enum variant,
     * but is not implemented on the SDK by default. To enable EIP-191, you need
     * to pass a custom `TxConfig` that has an implementation of
     * `SignModeHandler` for EIP-191. The SDK may decide to fully support
     * EIP-191 in the future.
     *
     * Since: cosmos-sdk 0.45.2
     */
    SIGN_MODE_EIP_191 = 191,
    UNRECOGNIZED = -1
}
export declare function signModeFromJSON(object: any): SignMode;
export declare function signModeToJSON(object: SignMode): string;
/**
 * SignatureDescriptors wraps multiple SignatureDescriptor's.
 * @name SignatureDescriptors
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.SignatureDescriptors
 */
export interface SignatureDescriptors {
    /**
     * signatures are the signature descriptors
     */
    signatures: SignatureDescriptor[];
}
/**
 * SignatureDescriptor is a convenience type which represents the full data for
 * a signature including the public key of the signer, signing modes and the
 * signature itself. It is primarily used for coordinating signatures between
 * clients.
 * @name SignatureDescriptor
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.SignatureDescriptor
 */
export interface SignatureDescriptor {
    /**
     * public_key is the public key of the signer
     */
    publicKey?: Any;
    data?: SignatureDescriptor_Data;
    /**
     * sequence is the sequence of the account, which describes the
     * number of committed transactions signed by a given address. It is used to prevent
     * replay attacks.
     */
    sequence: bigint;
}
/**
 * Data represents signature data
 * @name SignatureDescriptor_Data
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Data
 */
export interface SignatureDescriptor_Data {
    /**
     * single represents a single signer
     */
    single?: SignatureDescriptor_Data_Single;
    /**
     * multi represents a multisig signer
     */
    multi?: SignatureDescriptor_Data_Multi;
}
/**
 * Single is the signature data for a single signer
 * @name SignatureDescriptor_Data_Single
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Single
 */
export interface SignatureDescriptor_Data_Single {
    /**
     * mode is the signing mode of the single signer
     */
    mode: SignMode;
    /**
     * signature is the raw signature bytes
     */
    signature: Uint8Array;
}
/**
 * Multi is the signature data for a multisig public key
 * @name SignatureDescriptor_Data_Multi
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Multi
 */
export interface SignatureDescriptor_Data_Multi {
    /**
     * bitarray specifies which keys within the multisig are signing
     */
    bitarray?: CompactBitArray;
    /**
     * signatures is the signatures of the multi-signature
     */
    signatures: SignatureDescriptor_Data[];
}
/**
 * SignatureDescriptors wraps multiple SignatureDescriptor's.
 * @name SignatureDescriptors
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.SignatureDescriptors
 */
export declare const SignatureDescriptors: {
    typeUrl: string;
    aminoType: string;
    encode(message: SignatureDescriptors, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignatureDescriptors;
    fromPartial(object: DeepPartial<SignatureDescriptors>): SignatureDescriptors;
};
/**
 * SignatureDescriptor is a convenience type which represents the full data for
 * a signature including the public key of the signer, signing modes and the
 * signature itself. It is primarily used for coordinating signatures between
 * clients.
 * @name SignatureDescriptor
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.SignatureDescriptor
 */
export declare const SignatureDescriptor: {
    typeUrl: string;
    aminoType: string;
    encode(message: SignatureDescriptor, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignatureDescriptor;
    fromPartial(object: DeepPartial<SignatureDescriptor>): SignatureDescriptor;
};
/**
 * Data represents signature data
 * @name SignatureDescriptor_Data
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Data
 */
export declare const SignatureDescriptor_Data: {
    typeUrl: string;
    aminoType: string;
    encode(message: SignatureDescriptor_Data, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignatureDescriptor_Data;
    fromPartial(object: DeepPartial<SignatureDescriptor_Data>): SignatureDescriptor_Data;
};
/**
 * Single is the signature data for a single signer
 * @name SignatureDescriptor_Data_Single
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Single
 */
export declare const SignatureDescriptor_Data_Single: {
    typeUrl: string;
    aminoType: string;
    encode(message: SignatureDescriptor_Data_Single, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignatureDescriptor_Data_Single;
    fromPartial(object: DeepPartial<SignatureDescriptor_Data_Single>): SignatureDescriptor_Data_Single;
};
/**
 * Multi is the signature data for a multisig public key
 * @name SignatureDescriptor_Data_Multi
 * @package cosmos.tx.signing.v1beta1
 * @see proto type: cosmos.tx.signing.v1beta1.Multi
 */
export declare const SignatureDescriptor_Data_Multi: {
    typeUrl: string;
    aminoType: string;
    encode(message: SignatureDescriptor_Data_Multi, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): SignatureDescriptor_Data_Multi;
    fromPartial(object: DeepPartial<SignatureDescriptor_Data_Multi>): SignatureDescriptor_Data_Multi;
};
