import { Duration } from "../../google/protobuf/duration";
import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
/**
 * ConsensusParams contains consensus critical parameters that determine the
 * validity of blocks.
 * @name ConsensusParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ConsensusParams
 */
export interface ConsensusParams {
    block?: BlockParams;
    evidence?: EvidenceParams;
    validator?: ValidatorParams;
    version?: VersionParams;
    abci?: ABCIParams;
}
/**
 * BlockParams contains limits on the block size.
 * @name BlockParams
 * @package tendermint.types
 * @see proto type: tendermint.types.BlockParams
 */
export interface BlockParams {
    /**
     * Max block size, in bytes.
     * Note: must be greater than 0
     */
    maxBytes: bigint;
    /**
     * Max gas per block.
     * Note: must be greater or equal to -1
     */
    maxGas: bigint;
}
/**
 * EvidenceParams determine how we handle evidence of malfeasance.
 * @name EvidenceParams
 * @package tendermint.types
 * @see proto type: tendermint.types.EvidenceParams
 */
export interface EvidenceParams {
    /**
     * Max age of evidence, in blocks.
     *
     * The basic formula for calculating this is: MaxAgeDuration / {average block
     * time}.
     */
    maxAgeNumBlocks: bigint;
    /**
     * Max age of evidence, in time.
     *
     * It should correspond with an app's "unbonding period" or other similar
     * mechanism for handling [Nothing-At-Stake
     * attacks](https://github.com/ethereum/wiki/wiki/Proof-of-Stake-FAQ#what-is-the-nothing-at-stake-problem-and-how-can-it-be-fixed).
     */
    maxAgeDuration: Duration;
    /**
     * This sets the maximum size of total evidence in bytes that can be committed in a single block.
     * and should fall comfortably under the max block bytes.
     * Default is 1048576 or 1MB
     */
    maxBytes: bigint;
}
/**
 * ValidatorParams restrict the public key types validators can use.
 * NOTE: uses ABCI pubkey naming, not Amino names.
 * @name ValidatorParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ValidatorParams
 */
export interface ValidatorParams {
    pubKeyTypes: string[];
}
/**
 * VersionParams contains the ABCI application version.
 * @name VersionParams
 * @package tendermint.types
 * @see proto type: tendermint.types.VersionParams
 */
export interface VersionParams {
    app: bigint;
}
/**
 * HashedParams is a subset of ConsensusParams.
 *
 * It is hashed into the Header.ConsensusHash.
 * @name HashedParams
 * @package tendermint.types
 * @see proto type: tendermint.types.HashedParams
 */
export interface HashedParams {
    blockMaxBytes: bigint;
    blockMaxGas: bigint;
}
/**
 * ABCIParams configure functionality specific to the Application Blockchain Interface.
 * @name ABCIParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ABCIParams
 */
export interface ABCIParams {
    /**
     * vote_extensions_enable_height configures the first height during which
     * vote extensions will be enabled. During this specified height, and for all
     * subsequent heights, precommit messages that do not contain valid extension data
     * will be considered invalid. Prior to this height, vote extensions will not
     * be used or accepted by validators on the network.
     *
     * Once enabled, vote extensions will be created by the application in ExtendVote,
     * passed to the application for validation in VerifyVoteExtension and given
     * to the application to use when proposing a block during PrepareProposal.
     */
    voteExtensionsEnableHeight: bigint;
}
/**
 * ConsensusParams contains consensus critical parameters that determine the
 * validity of blocks.
 * @name ConsensusParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ConsensusParams
 */
export declare const ConsensusParams: {
    typeUrl: string;
    encode(message: ConsensusParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConsensusParams;
    fromPartial(object: DeepPartial<ConsensusParams>): ConsensusParams;
};
/**
 * BlockParams contains limits on the block size.
 * @name BlockParams
 * @package tendermint.types
 * @see proto type: tendermint.types.BlockParams
 */
export declare const BlockParams: {
    typeUrl: string;
    encode(message: BlockParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): BlockParams;
    fromPartial(object: DeepPartial<BlockParams>): BlockParams;
};
/**
 * EvidenceParams determine how we handle evidence of malfeasance.
 * @name EvidenceParams
 * @package tendermint.types
 * @see proto type: tendermint.types.EvidenceParams
 */
export declare const EvidenceParams: {
    typeUrl: string;
    encode(message: EvidenceParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): EvidenceParams;
    fromPartial(object: DeepPartial<EvidenceParams>): EvidenceParams;
};
/**
 * ValidatorParams restrict the public key types validators can use.
 * NOTE: uses ABCI pubkey naming, not Amino names.
 * @name ValidatorParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ValidatorParams
 */
export declare const ValidatorParams: {
    typeUrl: string;
    encode(message: ValidatorParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ValidatorParams;
    fromPartial(object: DeepPartial<ValidatorParams>): ValidatorParams;
};
/**
 * VersionParams contains the ABCI application version.
 * @name VersionParams
 * @package tendermint.types
 * @see proto type: tendermint.types.VersionParams
 */
export declare const VersionParams: {
    typeUrl: string;
    encode(message: VersionParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): VersionParams;
    fromPartial(object: DeepPartial<VersionParams>): VersionParams;
};
/**
 * HashedParams is a subset of ConsensusParams.
 *
 * It is hashed into the Header.ConsensusHash.
 * @name HashedParams
 * @package tendermint.types
 * @see proto type: tendermint.types.HashedParams
 */
export declare const HashedParams: {
    typeUrl: string;
    encode(message: HashedParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): HashedParams;
    fromPartial(object: DeepPartial<HashedParams>): HashedParams;
};
/**
 * ABCIParams configure functionality specific to the Application Blockchain Interface.
 * @name ABCIParams
 * @package tendermint.types
 * @see proto type: tendermint.types.ABCIParams
 */
export declare const ABCIParams: {
    typeUrl: string;
    encode(message: ABCIParams, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ABCIParams;
    fromPartial(object: DeepPartial<ABCIParams>): ABCIParams;
};
